<?php

namespace Drp\ProjectHelpers\Tests\Concerns;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Collection;
use PHPUnit\Framework\Assert;

/**
 * Class InteractsWithModels
 * @package Drp\ProjectHelpers
 */
trait InteractsWithModels
{
    /**
     * @param Model $expected
     * @param Model $actual
     * @return static
     */
    public function assertSameModel(Model $expected, $actual)
    {
        Assert::assertTrue(ModelChecker::isSameModel($expected, $actual), 'Failed asserting that two models are the same');

        return $this;
    }

    /**
     * @param Model $expected
     * @param Model $actual
     * @return static
     */
    public function assertNotSameModel(Model $expected, Model $actual)
    {
        Assert::assertFalse(ModelChecker::isSameModel($expected, $actual), 'Failed asserting that two models are not the same');

        return $this;
    }



    /**
     * @param Model $expected
     * @param \Illuminate\Support\Collection|array $collection
     * @return static
     */
    public function assertContainsModel(Model $expected, $collection)
    {
        if (is_array($collection)) {
            $collection = new Collection($collection);
        }

        $collection->assertContainsModel($expected);

        return $this;
    }

    /**
     * @param Model $expected
     * @param \Illuminate\Support\Collection|array $collection
     * @return static
     */
    public function assertNotContainsModel(Model $expected, $collection)
    {
        if (is_array($collection)) {
            $collection = new Collection($collection);
        }

        $collection->assertNotContainsModel($expected);

        return $this;
    }
}
